@@ -77,10 +77,27 @@ PNI.Scenario = function(arg) {
     this.currenSlot = undefined;
     this.semiEdge = undefined;
 
+    // Render elems that are already created.
+    this.updateView();
+
     var that = this;
 
+    this.$container.click( function(e) {
+
+        if( that.nodeSelector.visible ) {
+            that.nodeSelector.hide();
+            return;
+        }
+
+    });
+
     this.$container.dblclick( function(e) {
 
+        //if( that.nodeSelector.visible ) {
+        //    that.nodeSelector.hide();
+        //    return;
+        //}
+
         var $offset = that.$container.offset();
         var x = e.pageX - $offset.left; 
         var y = e.pageY - $offset.top;
@@ -137,30 +154,42 @@ PNI.Scenario.prototype = {
 
         });
 
-    }
+    },
 
-    /*
-    update: function() {
+    updateView: function() {
 
-    var controllerRoute = '/scenario/'+this.id;
+        var controllerRoute = '/scenario/'+this.id;
 
-    var requestData = {};
+        var requestData = {};
 
-    var that = this;
+        var that = this;
 
-    $j.getJSON(controllerRoute,requestData, function(responseData){
+        $j.getJSON(controllerRoute,requestData, function(responseData){
 
-    for ( var i in responseData.nodes ) {
+            for ( var i in responseData.nodes ) {
 
-    var arg = responseData.nodes[i];
-    //arg.scenario = that;
-    //var node = new PNI.Node(arg);
-    } 
+                var arg = responseData.nodes[i];
+                arg.scenario = that;
+                arg.stage = that.stage;
+                arg.layer = that.layer;
+                var node = new PNI.Node(arg);
+                
+            } 
 
-    });
+            for ( var i in responseData.edges ) {
+
+                var arg = responseData.edges[i];
+                arg.scenario = that;
+                arg.stage = that.stage;
+                arg.layer = that.layer;
+                var edge = new PNI.Edge(arg);
+                
+            } 
+
+        });
 
     }
-    */
+
 };
 
 PNI.extend(PNI.Scenario,PNI.Elem);
@@ -176,20 +205,36 @@ PNI.NodeSelector = function(arg) {
 
     this.$input = $j("#node-selector-input");
 
+    //this.visible = false;
+
 }
 
 PNI.NodeSelector.prototype = {
 
-    hide: function() { this.$container.hide(); },
+    hide: function() { 
+
+        //this.visible = false;
+
+        //this.$input.autocomplete("close");
+        //this.$input.val("");
+
+        this.$container.hide();
+
+    },
 
     show: function(x,y) { 
 
+        //this.visible = true;
+
+        //this.$input.val("");
+
         this.$container
         .css({left:x,top:y})
         .show()
         ;
 
         this.$input.focus();
+
     },
 
     update: function() {
@@ -215,9 +260,6 @@ PNI.Node = function(arg) {
     PNI.Elem.call(this,arg);
 
     this.height = 40;
-
-    // Node width is at least 3 times slotSide which seems a good choice
-    // for one char label nodes; it grows to adapt to label length.
     this.width = Math.max( arg.label.length * PNI.Theme.fontSize, 3 * PNI.Theme.slotSide );
 
     // Force x and y to be numbers since they come from JSON data.
@@ -379,13 +421,10 @@ PNI.Slot.prototype = {
 
     getX: function() {
 
-        var x = 0;
+        var x = this.node.x;
 
-        if( this.order === 0 ) {
-            x = this.node.x;
-        }
-        else { 
-            x = this.node.x + this.order * ( this.node.width - PNI.Theme.slotSide ) / ( this.node.ins.length - 1 ); 
+        if( this.order > 0 ) {
+            x += this.order * ( this.node.width - PNI.Theme.slotSide ) / ( this.node.ins.length - 1 ); 
         }
 
         return x;
